@@ -7,7 +7,7 @@ use warnings;
 use Carp;
 use parent 'LyricFinder::_Class';
 
-# LyricFinder - A Derived work, by (c) 2020 Jim Turner <turnerjw784 at yahoo.com> of:
+# LyricFinder - A Derived work, by (c) 2020-2024 Jim Turner <turnerjw784 at yahoo.com> of:
 #
 # Lyrics Fetcher
 #
@@ -34,10 +34,10 @@ use parent 'LyricFinder::_Class';
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
-our $VERSION = '1.23';
+our $VERSION = '1.30';
 our $DEBUG = 0;  # If you want debug messages, set debug to a true value
 
-my @supported_mods = (qw(Cache ApiLyricsOvh AZLyrics Genius Letras Musixmatch));
+my @supported_mods = (qw(Cache ApiLyricsOvh AZLyrics ChartLyrics Genius Letras Musixmatch));
 
 my %haveit;
 
@@ -223,7 +223,7 @@ LyricFinder - Fetch song lyrics from several internet lyric sites.
 
 =head1 AUTHOR
 
-This module is Copyright (c) 2020 by
+This module is Copyright (c) 2020-2024 by
 
 Jim Turner, C<< <turnerjw784 at yahoo.com> >>
 		
@@ -289,7 +289,8 @@ lyrics sites for song lyrics, and, if found, returns them as a string.
 
 The supported and currently-installed modules are:  
 L<LyricFinder::ApiLyricsOvh> (for searching api.lyrics.ovh), 
-L<LyricFinder::AZLyrics> (www.azlyrics.com), L<LyricFinder::Genius> 
+L<LyricFinder::AZLyrics> (www.azlyrics.com), 
+L<LyricFinder::ChartLyrics> (api.lyrics.com), L<LyricFinder::Genius> 
 (genius.com), L<LyricFinder::Letras> (www.letras.mus.br), and 
 L<LyricFinder::Musixmatch> (www.musixmatch.com).  There is a 
 special module for storing and / or fetching lyrics (.lrc) files already 
@@ -556,7 +557,8 @@ If an array reference (a list) of modules are provided, they will be searched
 in the order they appear in the list.
 
 The currently-installed and supported modules are:  ApiLyricsOvh, AZLyrics, 
-Genius, Letras, and Musixmatch (NOTE the "x" in the spelling of "Musixmatch")!
+ChartLyrics, Genius, Letras, and Musixmatch 
+(NOTE the "x" in the spelling of "Musixmatch")!
 
 Returns lyrics as a string (includes line-breaks appropriate for the user's 
 operating system), or an empty string, if no lyrics found.
@@ -564,9 +566,10 @@ operating system), or an empty string, if no lyrics found.
 =item I<$scalar> = $finder->B<image_url>()
 
 Returns a URL for a cover-art image, if one found on the lyrics page.  
-Currently, only the LyricFinder::Genius and LyricFinder::Musixmatch 
-sites contain cover-art images.  For the other sites, or if no image 
-is found, an empty string will be returned if this method is called.
+Currently, only the LyricFinder::ChartLyrics, LyricFinder::Genius and 
+LyricFinder::Musixmatch sites contain cover-art images.  For the other sites, 
+or if no image is found, an empty string will be returned if 
+this method is called.
 
 =item I<$scalar> = $finder->B<message>()
 
@@ -658,7 +661,7 @@ L<http://search.cpan.org/dist/LyricFinder/>
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright (c) 2020 Jim Turner.
+Copyright (c) 2020-2024 Jim Turner.
 
 This program is free software; you can redistribute it and/or modify it
 under the terms of the the Artistic License (2.0). You may obtain a
@@ -701,14 +704,14 @@ Original Lyrics::Fetcher::* work:
 Copyright (C) 2007-2020 David Precious.
 
 This library is free software; you can redistribute it and/or modify it 
-under the same terms as Perl itself, either Perl version 5.8.7 or, at your option, 
-any later version of Perl 5 you may have available.
+under the same terms as Perl itself, either Perl version 5.8.7 or, at your 
+option, any later version of Perl 5 you may have available.
 
-Legal disclaimer: I have no connection with the owners of www.genius.com. Lyrics 
-fetched by this script may be copyrighted by the authors, it's up to you to 
-determine whether this is the case, and if so, whether you are entitled to 
-request/use those lyrics. You will almost certainly not be allowed to use the 
-lyrics obtained for any commercial purposes.  
+Legal disclaimer: I have no connection with the owners of any of these sites.  
+Lyrics fetched by this script may be copyrighted by the authors, it's up to 
+you to determine whether this is the case, and if so, whether you are entitled 
+to request/use those lyrics. You will almost certainly not be allowed to use 
+the lyrics obtained for any commercial purposes.  
 
 All comments / suggestions / 
 bug reports gratefully received (ideally use the RT installation at 
