@@ -42,7 +42,7 @@ sub fetch {
 	# first, see if we've got it cached:
 	$self->_debug("i:haveCache=$haveLyricsCache= -cachedir=".$self->{'-cache'}."=");
 	if ($haveLyricsCache && $self->{'-cache'} && $self->{'-cache'} !~ /^\>/) {
-		my $cache = new Mod::Cache(%{$self});
+		my $cache = new LyricFinder::Cache(%{$self});
 		if ($cache) {
 			my $lyrics = $cache->fetch($artist_in, $song_in);
 			if (defined($lyrics) && $lyrics =~ /\w/) {
@@ -81,7 +81,6 @@ sub fetch {
 		$self->_debug("=== WILL CACHE LYRICS! ===");
 		# cache the fetched lyrics, if we can:
 		my $cache = new LyricFinder::Cache(%{$self});
-		my $res = 0;
 		$cache->save($artist_in, $song_in, $lyrics)  if ($cache);
 	}
 	return $lyrics;
@@ -96,6 +95,7 @@ sub _parse {
 	my $text = '';
 	my $mm_status = '';
 	my $hs   = HTML::Strip->new();
+
 	#METHOD 1:  MERGE LYRICS FROM BOTH (OR MORE?) LYRIC "SPANS" MM LIKES TO BREAK LYRICS UP INTO
 	#2 SEPARATE SPAN TAGS:  A SHORT (ABBREVIATED) PART, FOLLOWED BY THE REST OF THE LYRICS:
 	while ($html =~ s#\<span\s+class\=\"lyrics\_\_content\_\_(ok|warning|error)\"\>(.+?)\<\/span\>##s) {
@@ -116,6 +116,16 @@ sub _parse {
 		$text .= "\r\n(Musixmatch status: $mm_status)"
 				unless ((defined($self->{'-noextra'}) && $self->{'-noextra'}) || $mm_status !~ /\S/);
 
+		#WHILE WE'RE AT IT, SEE IF WE HAVE A COVER IMAGE?!:
+		if ($html =~ m#\<div\s+class\=\"banner\-album\-image\"\>(.+?)\<\/div\>#s) {
+			my $imgdiv = $1;
+			if ($imgdiv =~ m#\<img\s+src\=\"([^\"]+)#s) {
+				my $imgurl = $1;
+				$imgurl = 'https:' . $imgurl  if ($imgurl =~ m#^//#);
+				$self->{'image_url'} = $imgurl;
+			}
+		}
+
 		return $self->_normalize_lyric_text($self->_html2text($text));
 	} else {
 		carp($self->{'Error'} = "e:$Source - Failed to identify lyrics on result page.");
@@ -336,6 +346,12 @@ This is the primary method call, and the only one required to be called
 Returns lyrics as a string (includes line-breaks appropriate for the user's 
 operating system), or an empty string, if no lyrics found.
 
+=item I<$scalar> = $finder->B<image_url>()
+
+Returns a URL for a cover-art image, if one found on the lyrics page.  
+If no image is found, an empty string will be returned if this method 
+is called.
+
 =item I<$scalar> = $finder->B<message>()
 
 Returns the last error string generated, or "Ok" if all's well.
